Stan Math Library: stan::VectorView< T, true, false > Class Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | Public Member Functions | List of all members
stan::VectorView< T, true, false > Class Template Reference

`#include <VectorView.hpp>`

## Public Types
typedef boost::conditional< boost::is_const< T >::value, typename boost::add_const< typename scalar_type< T >::type >::type, typename scalar_type< T >::type >::type | scalar_t

## Public Member Functions
| VectorView (scalar_t *x)
scalar_t & | operator[] (int i)
scalar_t & | operator[] (int i) const

## Detailed Description

### template<typename T>
class stan::VectorView< T, true, false >

Definition at line 124 of file VectorView.hpp.

## Member Typedef Documentation

template<typename T >

typedef boost::conditional<boost::is_const<T>::value, typename boost::add_const< typename scalar_type<T>::type>::type, typename scalar_type<T>::type>::type stan::VectorView< T, true, false >::scalar_t

Definition at line 130 of file VectorView.hpp.

## Constructor & Destructor Documentation

template<typename T >

stan::VectorView< T, true, false >::VectorView | ( | scalar_t * | x | ) |
| inlineexplicit

Definition at line 132 of file VectorView.hpp.

## Member Function Documentation

template<typename T >

scalar_t& stan::VectorView< T, true, false >::operator[] | ( | int | i | ) |
| inline

Definition at line 134 of file VectorView.hpp.

template<typename T >

scalar_t& stan::VectorView< T, true, false >::operator[] | ( | int | i | ) | const
| inline

Definition at line 138 of file VectorView.hpp.

The documentation for this class was generated from the following file:

- stan/math/prim/scal/meta/VectorView.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.